# printj

[![Python: 3.6](https://img.shields.io/badge/Python-3.6-blue.svg)](#)
[![Build Status](https://travis-ci.org/GeorgiosGoniotakis/python-hierarchy.svg?branch=master)](https://github.com/Jitesh17/printj)
[![license: MIT](https://img.shields.io/badge/license-MIT-orange.svg)](https://opensource.org/licenses/MIT)



Print log info and color text, speak text and helps debugging.



## Installation
### Method 1: Pip install

```python
pip install printj
```

### Method 2

```python
pip install https://github.com/jitesh17/printj/archive/master.zip
```

### Method 3: Git clone

```python
git clone https://github.com/jitesh17/printj.git
cd prinj
pip install -e .
```


## Usage

- Script
    ```python
    import printj

    printj.red('YOUR TEXT')
    printj.bold('YOUR TEXT')
    printj.blue.italic_on_yellow('YOUR TEXT')
    ```
- Output
    
    ![](https://i.imgur.com/zaRgPU3.png)

 
